@@ -6,6 +6,7 @@ from .helpers import run_unit_tests
 from django.conf import settings
 from .helpers import print_default
 from .helpers import check_needed
+import re
 
 
 def check_flake(directory: str, verbose: bool, config_file: str, all: bool, flake: bool, variables_passed: bool) -> int:
@@ -61,13 +62,14 @@ def check_migrations(directory: str, verbose: bool, all: bool, migrations: bool,
     return 0
 
 
-def check_unit_tests(directory: str, verbose: bool, all: bool, tests: bool, variables_passed: bool) -> int:
+def check_unit_tests(directory: str, verbose: bool, all: bool, tests: bool, variables_passed: bool, test_coverage: bool) -> int:
     if check_needed(all, tests, variables_passed):
+        command_pref = 'coverage run --source=. ' if check_needed(all, test_coverage, variables_passed) else ''
+
         if find_spec('pytest') is not None:
-            import re
             print_default('Django pytest')
             backend_dir = directory
-            cmd = f'pytest {backend_dir}'
+            cmd = f'{command_pref}pytest {backend_dir}'
             lines = shell_run(cmd)
             tests_count: list = re.findall(r'collected (\d+) item', lines)
             passed_count: list = re.findall(r'(\d+) passed', lines)
@@ -81,6 +83,10 @@ def check_unit_tests(directory: str, verbose: bool, all: bool, tests: bool, vari
             return 1
         else:
             print_default('Django unit tests')
+
+            if command_pref != '':
+                shell_run(f'{command_pref}{directory}/manage.py test')
+
             failures, output = run_unit_tests(())
 
             if failures:
@@ -103,6 +109,29 @@ def check_garpix_page_tests(verbose: bool, all: bool, garpix_page: bool, variabl
     return 0
 
 
+def check_test_coverage(verbose: bool, all: bool, coverage: bool, variables_passed: bool) -> (int, int):
+
+    coverage_result = -1
+
+    if check_needed(all, coverage, variables_passed):
+
+        print_default('Test coverage')
+
+        cmd = 'coverage report'
+        lines = shell_run(cmd)
+
+        result_line: list = re.findall(r'TOTAL[ \d]+ (\d+)%', lines)
+
+        coverage_result = int(result_line[0])
+
+        if coverage_result < getattr(settings, 'TEST_COVERAGE_RATE', 70):
+            print_error(lines)
+            return 1, coverage_result
+        print_ok('', verbose)
+
+    return 0, coverage_result
+
+
 def check_lighthouse(verbose: bool = False, clear_reports: bool = False, all: bool = False) -> int:
     if all:
         print_default('Lighthouse CI')
